
From: "Antonino A. Daplas" <adaplas@hotpop.com>

  This patch fixes a few bugs with the low level logo code.

  1. Allow DEC Alpha machines to draw the DEC logo
  2. Cleanup the logo directory on a make clean
  3. Some makefile cleanups.

  I have tested on my local machines. I like to be able to create the C
  files from the logos for only the ones we want to compile but I haven't
  figured out how to do that. That can wait. Please apply.

Signed-off-by: James Simmons <jsimmons@www.infradead.org>
Signed-off-by: Antonino Daplas <adaplas@pol.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/video/logo/Kconfig  |    2 -
 25-akpm/drivers/video/logo/Makefile |   41 ++++++++++++++++--------------------
 25-akpm/drivers/video/logo/logo.c   |    4 ++-
 3 files changed, 23 insertions(+), 24 deletions(-)

diff -puN drivers/video/logo/Kconfig~fbdev-logo-code-fixes drivers/video/logo/Kconfig
--- 25/drivers/video/logo/Kconfig~fbdev-logo-code-fixes	Thu Feb 17 17:21:35 2005
+++ 25-akpm/drivers/video/logo/Kconfig	Thu Feb 17 17:21:35 2005
@@ -25,7 +25,7 @@ config LOGO_LINUX_CLUT224
 
 config LOGO_DEC_CLUT224
 	bool "224-color Digital Equipment Corporation Linux logo"
-	depends on LOGO && MACH_DECSTATION
+	depends on LOGO && (MACH_DECSTATION || ALPHA)
 	default y
 
 config LOGO_MAC_CLUT224
diff -puN drivers/video/logo/logo.c~fbdev-logo-code-fixes drivers/video/logo/logo.c
--- 25/drivers/video/logo/logo.c~fbdev-logo-code-fixes	Thu Feb 17 17:21:35 2005
+++ 25-akpm/drivers/video/logo/logo.c	Thu Feb 17 17:21:35 2005
@@ -66,8 +66,10 @@ const struct linux_logo *fb_find_logo(in
 		logo = &logo_linux_clut224;
 #endif
 #ifdef CONFIG_LOGO_DEC_CLUT224
-		/* DEC Linux logo on MIPS/MIPS64 */
+		/* DEC Linux logo on MIPS/MIPS64 or ALPHA */
+#ifndef CONFIG_ALPHA
 		if (mips_machgroup == MACH_GROUP_DEC)
+#endif
 			logo = &logo_dec_clut224;
 #endif
 #ifdef CONFIG_LOGO_MAC_CLUT224
diff -puN drivers/video/logo/Makefile~fbdev-logo-code-fixes drivers/video/logo/Makefile
--- 25/drivers/video/logo/Makefile~fbdev-logo-code-fixes	Thu Feb 17 17:21:35 2005
+++ 25-akpm/drivers/video/logo/Makefile	Thu Feb 17 17:21:35 2005
@@ -23,35 +23,32 @@ logo-cfiles = $(notdir $(patsubst %.$(2)
 # Mono logos
 extra-y += $(call logo-cfiles,_mono,pbm)
 
-quiet_cmd_logo_mono    = MONO    $@
-      cmd_logo_mono    = scripts/pnmtologo -t mono -n $*_mono -o $@ $<
-
-$(obj)/%_mono.c: $(src)/%_mono.pbm FORCE
-	$(call if_changed,logo_mono)
-
 # VGA16 logos
 extra-y += $(call logo-cfiles,_vga16,ppm)
 
-quiet_cmd_logo_vga16   = VGA16   $@
-      cmd_logo_vga16   = scripts/pnmtologo -t vga16 -n $*_vga16 -o $@ $<
-
-$(obj)/%_vga16.c: $(src)/%_vga16.ppm FORCE
-	$(call if_changed,logo_vga16)
-
-#224 Logos
+# 224 Logos
 extra-y += $(call logo-cfiles,_clut224,ppm)
 
-quiet_cmd_logo_clut224 = CLUT224 $@
-      cmd_logo_clut224 = scripts/pnmtologo -t clut224 -n $*_clut224 -o $@ $<
-
-$(obj)/%_clut224.c: $(src)/%_clut224.ppm FORCE
-	$(call if_changed,logo_clut224)
-
 # Gray 256
 extra-y += $(call logo-cfiles,_gray256,pgm)
 
-quiet_cmd_logo_gray256 = GRAY256 $@
-      cmd_logo_gray256 = scripts/pnmtologo -t gray256 -n $*_gray256 -o $@ $<
+# Create commands like "pnmtologo -t mono -n logo_mac_mono -o ..."
+quiet_cmd_logo = LOGO	$@
+	cmd_logo = scripts/pnmtologo \
+			-t $(patsubst $*_%,%,$(notdir $(basename $<))) \
+			-n $(notdir $(basename $<)) -o $@ $<
+
+$(obj)/%_mono.c: $(src)/%_mono.pbm FORCE
+	$(call if_changed,logo)
+
+$(obj)/%_vga16.c: $(src)/%_vga16.ppm FORCE
+	$(call if_changed,logo)
+
+$(obj)/%_clut224.c: $(src)/%_clut224.ppm FORCE
+	$(call if_changed,logo)
 
 $(obj)/%_gray256.c: $(src)/%_gray256.pgm FORCE
-	$(call if_changed,logo_gray256)
+	$(call if_changed,logo)
+
+# Files generated that shall be removed upon make clean
+clean-files := *.o *_mono.c *_vga16.c *_clut224.c *_gray256.c
_
